
/*  @(#)print.c 1.6 95/04/13
 *
 *  Various routines associated with the printing popup.
 *
 *  Copyright (c) Rich Burridge.    All rights reserved.
 *
 *  Permission is given to distribute these sources, as long as the
 *  copyright messages are not removed, and no monies are exchanged.
 *
 *  No responsibility is taken for any errors or inaccuracies inherent
 *  either to the comments or the code of this program, but if
 *  reported to me then an attempt will be made to fix them.
 */

#include "mptool.h"

Widget ppopup ;               /* Printing options popup. */
Widget *pwarr ;


static void
check_int_value(int *value, char *str,
                int minval, int maxval, int defval, int n)
{
  char m[MAXLINE] ;

  *value = get_int_value(F_PRINT, n) ;
  if (*value < minval || *value > maxval)
    {
      SPRINTF(m, str, defval) ;
      notice(pwarr[WI_PRINTING_FRAME], m) ;
      *value = defval ;
      set_int_value(F_PRINT, n, *value) ;
    }
}


void
do_printing_apply(void)
{
  int n ;

  check_int_value(&n, mptool_strs[(int) S_INVCOL],
                  1, MAXLINELENGTH, DEFCOLUMNS, WI_PRINT_COL) ;
  set_int_opt_val(O_NUMCOLS, n) ;
  check_int_value(&n, mptool_strs[(int) S_INVTAB],
                  1, MAXLINELENGTH, TABSIZE, WI_PRINT_TAB) ;
  set_int_opt_val(O_TABSIZE, n) ;
  check_int_value(&n, mptool_strs[(int) S_BMARGIN],
                  0, MAXMARGIN, DEFMARGIN, WI_PRINT_BMARGIN) ;
  set_margin(M_BOTTOM, n) ;
  check_int_value(&n, mptool_strs[(int) S_LMARGIN], 
                  0, MAXMARGIN, DEFMARGIN, WI_PRINT_LMARGIN) ;
  set_margin(M_LEFT, n) ;
  check_int_value(&n, mptool_strs[(int) S_RMARGIN], 
                  0, MAXMARGIN, DEFMARGIN, WI_PRINT_RMARGIN) ;
  set_margin(M_RIGHT, n) ;
  check_int_value(&n, mptool_strs[(int) S_TMARGIN], 
                  0, MAXMARGIN, DEFMARGIN, WI_PRINT_TMARGIN) ;
  set_margin(M_TOP, n) ;

  set_int_opt_val(O_BURSTPAGE, get_bool_value(F_PRINT, WI_PRINT_HEADER)) ;
  set_int_opt_val(O_WRAPW,     get_bool_value(F_PRINT, WI_PRINT_WRAP)) ;
  set_int_opt_val(O_FLIP,      get_bool_value(F_PRINT, WI_PRINT_FLIP)) ;
  set_int_opt_val(O_FORCEPAGE, get_bool_value(F_PRINT, WI_PRINT_FORCEPAGE)) ;
  set_int_opt_val(O_NUMBER,    get_bool_value(F_PRINT, WI_PRINT_NUMBER)) ;
  set_int_opt_val(O_TUMBLE,    get_bool_value(F_PRINT, WI_PRINT_REVERSE)) ;
}       


void
do_printing_dismiss(void)
{       
  XtUnmapWidget(ppopup) ;
  XtUnmanageChild(ppopup) ;
}       


void
do_printing_reset(void)
{       
  set_int_value(F_PRINT,  WI_PRINT_COL,       int_opt_val(O_NUMCOLS)) ;
  set_int_value(F_PRINT,  WI_PRINT_TAB,       int_opt_val(O_TABSIZE)) ;
  set_int_value(F_PRINT,  WI_PRINT_BMARGIN,   get_margin(M_BOTTOM)) ;
  set_int_value(F_PRINT,  WI_PRINT_LMARGIN,   get_margin(M_LEFT)) ;
  set_int_value(F_PRINT,  WI_PRINT_RMARGIN,   get_margin(M_RIGHT)) ;
  set_int_value(F_PRINT,  WI_PRINT_TMARGIN,   get_margin(M_TOP)) ;
  set_bool_value(F_PRINT, WI_PRINT_HEADER,    int_opt_val(O_BURSTPAGE)) ;
  set_bool_value(F_PRINT, WI_PRINT_WRAP,      int_opt_val(O_WRAPW)) ;
  set_bool_value(F_PRINT, WI_PRINT_FLIP,      int_opt_val(O_FLIP)) ;
  set_bool_value(F_PRINT, WI_PRINT_FORCEPAGE, int_opt_val(O_FORCEPAGE)) ;
  set_bool_value(F_PRINT, WI_PRINT_NUMBER,    int_opt_val(O_NUMBER)) ;
  set_bool_value(F_PRINT, WI_PRINT_REVERSE,   int_opt_val(O_TUMBLE)) ;
}


void
do_show_printing(void)
{
  if (!ppopup)
    {
      ppopup = tu_printing_frame_widget("printing", warr[WI_MAIN_FRAME],
                                        &pwarr) ;
      add_delete_callback(ppopup) ;
      add_help(pwarr[WI_PRINTING_FORM],     wi_props_frame_help) ;
      add_help(pwarr[WI_PRINT_COL_LABEL],   wi_props_col_help) ;
      add_help(pwarr[WI_PRINT_COL],         wi_props_col_help) ;
      add_help(pwarr[WI_PRINT_TAB_LABEL],   wi_props_tab_help) ;
      add_help(pwarr[WI_PRINT_TAB],         wi_props_tab_help) ;
      add_help(pwarr[WI_PRINT_BMARGIN],     wi_props_margin_help) ;
      add_help(pwarr[WI_PRINT_LMARGIN],     wi_props_margin_help) ;
      add_help(pwarr[WI_PRINT_RMARGIN],     wi_props_margin_help) ;
      add_help(pwarr[WI_PRINT_TMARGIN],     wi_props_margin_help) ;
      add_help(pwarr[WI_PRINT_BMLABEL],     wi_props_margin_help) ;
      add_help(pwarr[WI_PRINT_LMLABEL],     wi_props_margin_help) ;
      add_help(pwarr[WI_PRINT_RMLABEL],     wi_props_margin_help) ;
      add_help(pwarr[WI_PRINT_TMLABEL],     wi_props_margin_help) ;
      add_help(pwarr[WI_PRINT_MLABEL],      wi_props_margin_help) ;
      add_help(pwarr[WI_PRINT_HEADER],      wi_opt_header_help) ;
      add_help(pwarr[WI_PRINT_WRAP],        wi_props_wrap_help) ;
      add_help(pwarr[WI_PRINT_FLIP],        wi_props_flip_help) ;
      add_help(pwarr[WI_PRINT_FORCEPAGE],   wi_props_forcepage_help) ;
      add_help(pwarr[WI_PRINT_NUMBER],      wi_props_number_help) ;
      add_help(pwarr[WI_PRINT_REVERSE],     wi_props_reverse_help) ;
      add_help(pwarr[WI_PRINT_APPLY],       wi_props_apply_help) ;
      add_help(pwarr[WI_PRINT_RESET],       wi_props_reset_help) ;
      add_help(pwarr[WI_PRINT_DISMISS],     wi_props_dismiss_help) ;
      do_printing_reset() ;
    } 
  show_popup(ppopup) ;
}


void
Print(void)
{  
  pwarr = NULL ;           /* No widgets defined initially. */
  ppopup = NULL ;          /* No printing popup window initially. */
}
